Throw - A simple file sharing solution
======================================

Throw is a simple utility designed to allow you to share a file, set of files
or directory of files quickly and easily from the command-line.

Usage
-----

To send the file 'funny-picture.png' to 'steve@example.com', just do the
following:

    $ throw --to steve@example.com funny-picture.png

If you omit the `--to steve@example.com`, throw will ask you for the e-mail
address to send the file to.
